summaryrefslogtreecommitdiffstats
path: root/src/sbus
diff options
context:
space:
mode:
Diffstat (limited to 'src/sbus')
-rw-r--r--src/sbus/sssd_dbus_connection.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/sbus/sssd_dbus_connection.c b/src/sbus/sssd_dbus_connection.c
index d2918fbc..9faf3d9f 100644
--- a/src/sbus/sssd_dbus_connection.c
+++ b/src/sbus/sssd_dbus_connection.c
@@ -58,7 +58,8 @@ static void sbus_dispatch(struct tevent_context *ev,
if (conn->retries > 0) {
DEBUG(6, ("SBUS is reconnecting. Deferring.\n"));
- /* Currently trying to reconnect, defer dispatch */
+ /* Currently trying to reconnect, defer dispatch for 30ms */
+ tv = tevent_timeval_current_ofs(0, 30);
new_event = tevent_add_timer(ev, conn, tv, sbus_dispatch, conn);
if (new_event == NULL) {
DEBUG(0,("Could not defer dispatch!\n"));